@@ -33,7 +33,8 @@
 #define CHECK_VASTATUS(va_status,func, ret)                             \
 if (va_status != VA_STATUS_SUCCESS) {                                   \
     fprintf(stderr,"%s failed with error code %d (%s),exit\n",func, va_status, vaErrorStr(va_status)); \
-    exit(ret);                                                          \
+    ret_val = ret;                                                      \
+    goto error;                                                         \
 }
 
 static char * profile_string(VAProfile profile)
@@ -54,6 +55,8 @@ static char * profile_string(VAProfile profile)
             case VAProfileH263Baseline: return "VAProfileH263Baseline";
             case VAProfileH264ConstrainedBaseline: return "VAProfileH264ConstrainedBaseline";
             case VAProfileJPEGBaseline: return "VAProfileJPEGBaseline";
+            case VAProfileVP8Version0_3: return "VAProfileVP8Version0_3";
+
             default:
                 break;
     }
@@ -85,9 +88,11 @@ int main(int argc, const char* argv[])
   int major_version, minor_version;
   const char *driver;
   const char *name = strrchr(argv[0], '/'); 
-  VAProfile profile;
+  VAProfile profile, *profile_list = NULL;
+  int num_profiles, max_num_profiles, i;
   VAEntrypoint entrypoint, entrypoints[10];
   int num_entrypoint;
+  int ret_val = 0;
   
   if (name)
       name++;
@@ -111,9 +116,22 @@ int main(int argc, const char* argv[])
   printf("%s: Driver version: %s\n", name, driver ? driver : "<unknown>");
 
   printf("%s: Supported profile and entrypoints\n", name);
-  for	(profile = VAProfileNone; profile <= VAProfileH264ConstrainedBaseline; profile++) {
+  max_num_profiles = vaMaxNumProfiles(va_dpy);
+  profile_list = malloc(max_num_profiles * sizeof(VAProfile));
+
+  if (!profile_list) {
+      printf("Failed to allocate memory for profile list\n");
+      ret_val = 5;
+      goto error;
+  }
+
+  va_status = vaQueryConfigProfiles(va_dpy, profile_list, &num_profiles);
+  CHECK_VASTATUS(va_status, "vaQueryConfigProfiles", 6);
+
+  for (i = 0; i < num_profiles; i++) {
       char *profile_str;
 
+      profile = profile_list[i];
       va_status = vaQueryConfigEntrypoints(va_dpy, profile, entrypoints, 
                                            &num_entrypoint);
       if (va_status == VA_STATUS_ERROR_UNSUPPORTED_PROFILE)
@@ -126,8 +144,10 @@ int main(int argc, const char* argv[])
           printf("      %-32s:	%s\n", profile_str, entrypoint_string(entrypoints[entrypoint]));
   }
   
+error:
+  free(profile_list);
   vaTerminate(va_dpy);
   va_close_display(va_dpy);
   
-  return 0;
+  return ret_val;
 }
